@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
+/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXPROXY, NX protocol compression and NX extensions to this software    */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -115,8 +115,8 @@ int MaskImage(const ColorMask *mask, XImage *src_image, XImage *dst_image)
       fprintf(stderr, " -> 0x%lx\n", pixel);
       #endif
     }
-    return 1;
 
+    return 1;
   }
   else if (src_image -> bits_per_pixel == 16)
   {
@@ -200,7 +200,6 @@ int MaskImage(const ColorMask *mask, XImage *src_image, XImage *dst_image)
     *
     * End of FIXME.
     */
-
   }
   else
   {
@@ -687,7 +686,7 @@ int PackImage(unsigned int method, unsigned int src_data_size, XImage *src_image
   unsigned int dst_bits_per_pixel;
 
   src_bits_per_pixel = src_image -> bits_per_pixel;
-  dst_bits_per_pixel = GetBitsPerPixel(method);
+  dst_bits_per_pixel = MethodBitsPerPixel(method);
 
   #ifdef TEST
   fprintf(stderr, "******PackImage: Source bits per pixel [%d], destination bits per pixel [%d].\n",
@@ -769,3 +768,27 @@ int PackImage(unsigned int method, unsigned int src_data_size, XImage *src_image
     }
   }
 }
+
+/*
+ * Replace the ffs() call that may be not
+ * present on some systems.
+ */
+
+int FindLSB(int word)
+{
+  int t = word;
+
+  int m = 1;
+  int i = 0;
+
+  for (; i < sizeof(word) << 3; i++, m <<= 1)
+  {
+    if (t & m)
+    {
+      return i + 1;
+    }
+  }
+
+  return 0;
+}
+
