@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
+/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXPROXY, NX protocol compression and NX extensions to this software    */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -15,12 +15,17 @@
 /*                                                                        */
 /**************************************************************************/
 
+#ifndef NXlibint_H
+#define NXlibint_H
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include <X11/Xlibint.h>
+#include "NXvars.h"
 
 #ifdef __cplusplus
 }
 #endif
+
+#endif /* NXlibint_H */
