@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001,2003 NoMachine, http://www.nomachine.com.           */
+/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXPROXY, NX protocol compression and NX extensions to this software    */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -21,12 +21,13 @@
 
 #include "NXlib.h"
 
+#include "Mask.h"
 #include "Tight.h"
 
 #define PANIC
 #define WARNING
-#undef TEST
-#undef DEBUG
+#undef  TEST
+#undef  DEBUG
 
 #define RGB24_TO_PIXEL32(r,g,b)                                 \
   (((CARD32)(r) & 0xFF) << format.redShift   |                  \
@@ -260,7 +261,8 @@ int NXEncodeTightInit(Display *dpy, Drawable drawable, Visual *visual, void *gc,
   {
     unsigned int linkType;
     unsigned int protoMajor, protoMinor, protoPatch;
-    int          karma, stopSize, dataLevel, streamLevel, deltaLevel;
+    int          frameTimeout, pingTimeout, splitMode, splitThreshold;
+    int          dataLevel, streamLevel, deltaLevel;
     int          i;
     unsigned int nxPackMethod;
     unsigned int nxPackQuality;
@@ -273,12 +275,14 @@ int NXEncodeTightInit(Display *dpy, Drawable drawable, Visual *visual, void *gc,
     format.depth        = image->depth;
     format.bitsPerPixel = image->bits_per_pixel;
     format.bigEndian    = image->bitmap_bit_order == MSBFirst;
-    format.redShift     = ffs(image->red_mask) - 1;
-    format.greenShift   = ffs(image->green_mask) - 1;
-    format.blueShift    = ffs(image->blue_mask) - 1;
-    format.redMax       = image->red_mask >> format.redShift;
-    format.greenMax     = image->green_mask >> format.greenShift;
-    format.blueMax      = image->blue_mask >> format.blueShift;
+
+    format.redShift   = FindLSB(image->red_mask) - 1;
+    format.greenShift = FindLSB(image->green_mask) - 1;
+    format.blueShift  = FindLSB(image->blue_mask) - 1;
+
+    format.redMax   = image->red_mask >> format.redShift;
+    format.greenMax = image->green_mask >> format.greenShift;
+    format.blueMax  = image->blue_mask >> format.blueShift;
 
     if (format.depth == 24 && format.bitsPerPixel == 32 &&
           format.redMax == 0xFF && format.greenMax == 0xFF &&
@@ -298,9 +302,10 @@ int NXEncodeTightInit(Display *dpy, Drawable drawable, Visual *visual, void *gc,
      */
 
     NXGetControlParameters(dpy, &linkType, &protoMajor, &protoMinor, &protoPatch,
-                               &karma, &stopSize, &nxPackMethod, &nxPackQuality,
-                                   &dataLevel, &streamLevel, &deltaLevel, &loadCache,
-                                       &saveCache, &startupCache);
+                               &protoMajor, &protoMinor, &protoPatch, &frameTimeout, &pingTimeout,
+                                   &splitMode, &splitThreshold, &nxPackMethod, &nxPackQuality,
+                                       &dataLevel, &streamLevel, &deltaLevel, &loadCache,
+                                           &saveCache, &startupCache);
 
     #ifdef DEBUG
     fprintf(stderr, "******NXEncodeTightInit : dataLevel [%d]\n", dataLevel);
@@ -347,7 +352,7 @@ int NXEncodeTightInit(Display *dpy, Drawable drawable, Visual *visual, void *gc,
 
     packMethod = method;
     maskMethod = mask_method;
-    colormask = GetColorMask(maskMethod);
+    colormask = MethodColorMask(maskMethod);
 
     /*
      * Store the image pointer to free at
@@ -1855,7 +1860,7 @@ void FilterGradient24bpp(char *buf, tightPixelFormat *fmt, int w, int h)
   int prediction;
   int x, y, c;
 
-  buf8 = buf;
+  buf8 = (CARD8 *) buf;
   memset (prevRowBuf, 0, w * 3 * sizeof(int));
 
   shiftBits[0] = fmt->redShift;
